defaultValue property
dynamic
defaultValue
final
Default value used when the input key is missing or null.
Implementation
final dynamic defaultValue;
Default value used when the input key is missing or null.
final dynamic defaultValue;