UserProfile class

Annotations
  • @Serializable(naming: JsonNaming.snakeCase, strict: true, typeField: 'kind', discriminator: 'user_profile')

Constructors

UserProfile({required int id, required String fullName, required bool active, required UserStatus status, required DateTime birthDate, required DateTime createdAt, required List<String> tags, required Set<int> scores, required Map<String, String> metadata, required Address address, required Money balance, String internalToken = ''})
const

Properties

active bool
final
address Address
final
balance Money
final
birthDate DateTime
final
createdAt DateTime
final
fullName String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
internalToken String
final
metadata Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scores Set<int>
final
status UserStatus
final
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited