Format class
Field-level formatter configuration.
Constructors
- Format.custom(String name)
-
Uses custom formatter functions:
XFormatToJsonandXFormatFromJson.const - Format.customWith(Type formatterType)
-
Uses typed custom formatter functions:
TypeNameFormatToJsonandTypeNameFormatFromJson.const - Format.date(String pattern)
-
Formats dates using a supported pattern.
const
- Format.lowercase()
-
Converts string values to lowercase.
const
- Format.trim()
-
Trims leading and trailing whitespace.
const
- Format.uppercase()
-
Converts string values to uppercase.
const
Properties
- formatterType → Type?
-
Optional formatter type for typed custom formatters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
Formatter kind identifier used by codegen.
final
- pattern → String?
-
Optional formatter pattern, for example date patterns.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited