Serializer class
Static JSON serializer with type registration.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatDate(
DateTime value, String pattern) → String -
Formats a DateTime with a supported
pattern. -
fromJson<
T> (String json) → T -
Deserializes JSON text into type
T. -
parseDate(
String value, String pattern) → DateTime -
Parses a DateTime using a supported
pattern. -
register<
T> ({required JsonFactory< T> fromJson, required JsonEncoder<T> toJson}) → void - Registers conversion functions for a specific type.
-
toJson<
T> (T value) → String -
Serializes
valueto JSON text.